﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace Publishing
{
    /// <summary>
    /// Interaction logic for PrintWindow.xaml
    /// </summary>
    public partial class PrintWindow : Window
    {
        public PrintWindow()
        {
            InitializeComponent();
        }

        public string ShpFilePath { get; set; }


        private LegendAdornmentLayer _legendAdornmentLayer;
        private LegendAdornmentLayer LegendAdornmentLayer
        {
            get
            {
                if (_legendAdornmentLayer == null)
                    _legendAdornmentLayer = new LegendAdornmentLayer()
                    {
                        Height = 100,
                    };
                return _legendAdornmentLayer;
            }
        }



        void SetupMapWithBlankPage()
        {


            Map1.MapUnit = GeographyUnit.Meter;
            Map1.ZoomLevelSet = new PrinterZoomLevelSet(Map1.MapUnit,

                PrinterHelper.GetPointsPerGeographyUnit(Map1.MapUnit));
            Map1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.LightGray);

            Map1.Cursor = Cursors.Cross;
            Map1.Cursor = null;
            
            
            var printerOverlay = new PrinterInteractiveOverlay();



            Map1.InteractiveOverlays.Add("PrintPreviewOverlay", printerOverlay);

            Map1.InteractiveOverlays.MoveToBottom("PrintPreviewOverlay");

            var pagePrinterLayer = new PagePrinterLayer(PrinterPageSize.AnsiA, PrinterOrientation.Portrait);
            pagePrinterLayer.Open();
            printerOverlay.PrinterLayers.Add("PageLayer", pagePrinterLayer);

            Map1.CurrentExtent = AreaBaseShape.ScaleUp(pagePrinterLayer.GetPosition(), 10).GetBoundingBox();

            Map1.MinimumScale = Map1.ZoomLevelSet.ZoomLevel20.Scale;

        }


        void AddMapLayer()
        {
            var mapPrinterLayer = new MapPrinterLayer
            {
                MapUnit = GeographyUnit.Meter,
                BackgroundMask = new AreaStyle(new GeoPen(GeoColor.StandardColors.Black, 1))
            };

            mapPrinterLayer.Open();

            RectangleShape pageBoundingbox = GetPageBoundingBox(PrintingUnit.Inch);
            mapPrinterLayer.SetPosition(8, 7, pageBoundingbox.GetCenterPoint().X, pageBoundingbox.GetCenterPoint().Y + 1, PrintingUnit.Inch);
            var rectangleShape1 = AddShpFileToPrintLayer(mapPrinterLayer, this.ShpFilePath);
            var lst = new List<RectangleShape>();
            lst.Add(rectangleShape1);

            mapPrinterLayer.MapExtent = ExtentHelper.GetBoundingBoxOfItems(lst);

            var printerInteractiveOverlay = (PrinterInteractiveOverlay)Map1.InteractiveOverlays["PrintPreviewOverlay"];
            printerInteractiveOverlay.PrinterLayers.Add("MapLayer", mapPrinterLayer);



        }
        
        static RectangleShape AddShpFileToPrintLayer(MapPrinterLayer mapPrinterLayer, string shpFilePath)
        {
            var layer = new ShapeFileFeatureLayer(shpFilePath);

            layer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle =
                LineStyles.CreateSimpleLineStyle(GeoColor.SimpleColors.Red, 1, true);
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


            mapPrinterLayer.Layers.Add(layer);
            layer.Open();
            var rectangleShape1 = layer.GetBoundingBox();
            layer.Close();
            return rectangleShape1;
        }
        RectangleShape GetPageBoundingBox(PrintingUnit unit)
        {
            var printerInteractiveOverlay = (PrinterInteractiveOverlay)Map1.InteractiveOverlays["PrintPreviewOverlay"];
            var pagePrinterLayer = (PagePrinterLayer)printerInteractiveOverlay.PrinterLayers["PageLayer"];
            return pagePrinterLayer.GetPosition(unit);
        }
       

        private void PrintWindow_OnLoaded(object sender, RoutedEventArgs e)
        {
            Map1.Cursor = null;

            try
            {
                if (string.IsNullOrEmpty(ShpFilePath))
                    return;

                SetupMapWithBlankPage();
                AddMapLayer();


                Map1.Refresh();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message + " " + ex.StackTrace, "Exception");
            }
        }
      
      
     
    }
}
